@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
+# BioSTEAM: The Biorefinery Simulation and Techno-Economic Analysis Modules
+# Copyright (C) 2020, Yoel Cortes-Pena <yoelcortes@gmail.com>
+# 
+# This module is under the UIUC open-source license. See 
+# github.com/BioSTEAMDevelopmentGroup/biosteam/blob/master/LICENSE.txt
+# for license details.
 """
-Created on Tue Dec 10 22:54:15 2019
-
-@author: yoelr
 """
 from ._stream import Stream
 from ._thermal_condition import ThermalCondition
@@ -287,9 +290,11 @@ class MultiStream(Stream):
         return self._imol._phases
     @phases.setter
     def phases(self, phases):
+        if len(phases) == 1:
+            self.phase = phases[0]
         phases = sorted(phases)
         if phases != self.phases:
-            self._imol = self._imol.to_material_array(phases)
+            self._imol = self._imol.to_material_indexer(phases)
             self._init_cache()
     
     ### Flow properties ###
@@ -330,7 +335,7 @@ class MultiStream(Stream):
     @property
     def C(self):
         """[float] Heat capacity flow rate in kJ/hr."""
-        return self.mixture.xCn(self._imol, *self._thermal_condition)
+        return self.mixture.xCn(self._imol, self._thermal_condition.T)
     @property
     def F_vol(self):
         """[float] Total volumetric flow rate in m3/hr."""
