@@ -1,4 +1,18 @@
 # -*- coding: utf-8 -*-
+# BioSTEAM: The Biorefinery Simulation and Techno-Economic Analysis Modules
+# Copyright (C) 2020, Yoel Cortes-Pena <yoelcortes@gmail.com>
+# 
+# A significant portion of this module originates from:
+# Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+# Copyright (C) 2020 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+# 
+# This module is under a dual license:
+# 1. The UIUC open-source license. See 
+# github.com/BioSTEAMDevelopmentGroup/biosteam/blob/master/LICENSE.txt
+# for license details.
+# 
+# 2. The MIT open-source license. See
+# https://github.com/CalebBell/thermo/blob/master/LICENSE.txt for details.
 '''
 All UNIFAC groups are loaded here.
 '''
@@ -836,13 +850,8 @@ class GroupCounts(dict):
         cls.ids_by_group_name = {subgroup.group: key
                                  for key, subgroup in subgroups_by_id.items()}
     
-    def __init__(self, dict=None):
-        if dict: 
-            to_int = int
-            super().__init__({to_int(i): j for i,j in dict.items()})
-        
     @classmethod
-    def from_json_dict(cls, dict):
+    def from_dict(cls, dict):
         to_int = int
         self = cls()
         for i,j in dict.items(): self[to_int(i)] = j
@@ -898,10 +907,10 @@ class GroupAssigner:
         self.group_counts[key] = count
 
 data = load_json(folder, 'DDBST UNIFAC-original assignments.json')
-DDBST_UNIFAC_assignments = {i: UNIFACGroupCounts.from_json_dict(j) for i,j in data.items()}
+DDBST_UNIFAC_assignments = {i: UNIFACGroupCounts.from_dict(j) for i,j in data.items()}
 data = load_json(folder, 'DDBST UNIFAC-Dortmund assignments.json')
-DDBST_MODIFIED_UNIFAC_assignments = {i: DortmundGroupCounts.from_json_dict(j) for i,j in data.items()}
+DDBST_MODIFIED_UNIFAC_assignments = {i: DortmundGroupCounts.from_dict(j) for i,j in data.items()}
 data = load_json(folder, 'DDBST UNIFAC-original assignments.json')
-DDBST_PSRK_assignments = {i: PSRKGroupCounts.from_json_dict(j) for i,j in data.items()}
+DDBST_PSRK_assignments = {i: PSRKGroupCounts.from_dict(j) for i,j in data.items()}
 del data
 
